;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: COMP.asm
;;   Version: 2.0, Updated on 2010/12/27 at 15:27:10
;;  Generated by PSoC Designer 5.1.2101.0
;;
;;  DESCRIPTION: COMP User Module software implementation file
;;
;;  NOTE: User Module APIs conform to the fastcall16 convention for marshalling
;;        arguments and observe the associated "Registers are volatile" policy.
;;        This means it is the caller's responsibility to preserve any values
;;        in the X and A registers that are still needed after the API functions
;;        returns. For Large Memory Model devices it is also the caller's 
;;        responsibility to perserve any value in the CUR_PP, IDX_PP, MVR_PP and 
;;        MVW_PP registers. Even though some of these registers may not be modified
;;        now, there is no guarantee that will remain the case in future releases.
;;-----------------------------------------------------------------------------
;; Copyright (c) Cypress Semiconductor 2010. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "COMP.inc"

;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------

export  COMP_Start
export _COMP_Start
export  COMP_Stop
export _COMP_Stop
export  COMP_SetPower
export _COMP_SetPower
export  COMP_SetPolarity
export _COMP_SetPolarity
export  COMP_SetRef
export _COMP_SetRef

export  COMP_EnableInt
export _COMP_EnableInt
export  COMP_DisableInt
export _COMP_DisableInt
export  COMP_ClearInt
export _COMP_ClearInt

;-----------------------------------------------
;  Constant Definitions
;-----------------------------------------------

COMP_POLMASK:      equ 0x01
COMP_POWERMASK:    equ 0x03
COMP_REFMASK:      equ 0xF0
COMP_EXGAIN:       equ 0x01
COMP_GAINMASK:     equ 0xF4
COMP_HIGHGAINMASK: equ 0x10
COMP_HIGHGAIN:     equ 0x04

;-----------------------------------------------
; Variable Allocation
;-----------------------------------------------

AREA UserModules (ROM, REL)

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: COMP_Start
;  FUNCTION NAME: COMP_SetPower
;
;  DESCRIPTION:
;  Applies power setting to the module's analog blocks
;-----------------------------------------------------------------------------
;  ARGUMENTS:    
;   A  Contains the power settings 0=Off, 1=Low, 2=Med, and 3=High.
;  RETURNS:      Nothing.
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.

 COMP_Start:
_COMP_Start:
 COMP_SetPower:
_COMP_SetPower:

   RAM_PROLOGUE RAM_USE_CLASS_2
   and A, COMP_POWERMASK                         ; mask A to protect unchanged bits
   mov X, SP                                     ; define temp store location

   push A                                        ; put power value in temp store
   mov A, reg[COMP_CR2]                          ; read power value
   and A, ~COMP_POWERMASK                        ; clear power bits in A
   or  A, [X]                                    ; combine power value with balance of reg.
   mov reg[COMP_CR2], A
   pop A
   RAM_EPILOGUE RAM_USE_CLASS_2
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: COMP_Stop
;
;  DESCRIPTION:
;  Removes power setting to the module's analog blocks.
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.

 COMP_Stop:
_COMP_Stop:

   RAM_PROLOGUE RAM_USE_CLASS_1
   and   reg[COMP_CR2], ~COMP_POWERMASK   ; Turn off Power to analog block
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: COMP_SetRef
;
;  DESCRIPTION:
;    Sets comparator threshold at specified ratio between Low Limit and Vcc
;-----------------------------------------------------------------------------
;  ARGUMENTS:
;   A contains reference value.
;     Ref values shown are for example
;     1.000     f0h
;     0.937     e0h
;     ....
;     0.500     70h
;     ....
;     0.062     00h
;     0.042     14h
;     0.021     04h
;
;  RETURNS: none
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
 COMP_SetRef:
_COMP_SetRef:

   RAM_PROLOGUE RAM_USE_CLASS_2
   and  A, COMP_GAINMASK                         ; mask A to protect unchanged bits
   mov  X, SP                                    ; define temp store location
   push A                                        ; put reference value in temp store
   mov  A, reg[COMP_CR0]                         ; read old CR0 value
   and  A, ~COMP_REFMASK                         ; clear reference bits in A
   tst  [X], COMP_HIGHGAIN                       ; See if High Gain bit is set
   jnz  .sethigain
   
   and  reg[COMP_CR3], ~COMP_EXGAIN              ; Clear High Gain bit.
   jmp  .setlogain
   
.sethigain:
   or   reg[COMP_CR3], COMP_EXGAIN               ; Set High Gain bit.
   and  [X], COMP_HIGHGAINMASK                   ; Make sure we have a valid high gain
   
.setlogain:   
   or   A, [X]                                   ; combine gain value with balance of reg.
   mov  reg[COMP_CR0], A                         ; move complete value back to register
   pop  A
   RAM_EPILOGUE RAM_USE_CLASS_2
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: COMP_SetPolarity
;
;  DESCRIPTION:
;    Sets comparator output polarity;
;-----------------------------------------------------------------------------
;  ARGUMENTS:
;  A  Contains the polarity settings 0=Neg., 1=Pos.
;  RETURNS: none
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
 COMP_SetPolarity:
_COMP_SetPolarity:
   
   RAM_PROLOGUE RAM_USE_CLASS_2
   and  A, COMP_POLMASK
   jz   .lut_nA
   mov  A, COMP_LUT_A
   jmp  .lut_A
.lut_nA:   
   mov  A, COMP_LUT_NA
.lut_A:
   mov  X, SP
   push A
   M8C_SetBank1
   mov  A, reg[COMP_LUT_REG]
   and  A, ~COMP_LUT_MASK
   or   A, [X]
   mov  reg[COMP_LUT_REG], A
   M8C_SetBank0
   pop  A
   RAM_EPILOGUE RAM_USE_CLASS_2
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: COMP_EnableInt
;
;  DESCRIPTION:
;  Enables the Analog Column Interrupt
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.

 COMP_EnableInt:
_COMP_EnableInt:
   RAM_PROLOGUE RAM_USE_CLASS_1
//Enable the AColumn Interrupt
   or    reg[COMP_INT_REG],COMP_INT_MASK  ;enable ACol interrupt
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: COMP_DisableInt
;
;  DESCRIPTION:
;  Disables the Analog Column Interrupt
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.

 COMP_DisableInt:
_COMP_DisableInt:
   RAM_PROLOGUE RAM_USE_CLASS_1
//Disable the AColumn Interrupt
   and   reg[COMP_INT_REG],~COMP_INT_MASK  ;disable ACol interrupt
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: COMP_ClearInt
;
;  DESCRIPTION:
;  Cleares the pending Analog Column Interrupt
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.

 COMP_ClearInt:
_COMP_ClearInt:
   RAM_PROLOGUE RAM_USE_CLASS_1
//Cleare the pending AColumn Interrupt
   and   reg[COMP_INT_CLR_REG],~COMP_INT_MASK  ;clearing ACol interrupt
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

; End of File COMP.asm
