//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules
#include <stdlib.h>

#pragma interrupt_handler mesure;	// inter sur front montant digbuf (branché sur comparateur analogique)
void mesure(void);
#pragma interrupt_handler pasdemesure;	// inter sur compteur a 0 donc pas de rythme depuis 5s
void pasdemesure(void);

#define TAILLEBUF 2			// Definition de la taille du buffer I2C
BYTE txRxBuffer[TAILLEBUF];	// Definition du buffer I2C
BYTE status;				// Status I2C

void main(void)
{
	char ligne1[17] = "Periode rythme :";   // Definition d'une chaine de caracteres en RAM
	int i;
	
	PGA_Start(PGA_HIGHPOWER);
	LPF2_Start(3);
	CMPPRG_Start(3);
	LCD_Start();
	LCD_Init();
   	LCD_Position(0,0);            // Place le curseur du LCD premiere ligne à gauche  
   	LCD_PrString(ligne1);         // affichage du texte sur le LCD  
   	LCD_Position(1,0);            // Place le curseur du LCD deuxième ligne à gauche  
	M8C_EnableGInt ;
	DigBuf_EnableInt();			// détection d'un "pic"
	DigBuf_Start();
	Counter16_EnableInt();		// pas de detection de "pic" au bout de 5000ms
	Counter16_Start();
	I2CHW_Start();				// démarrage I2C en mode esclave
	I2CHW_EnableSlave();
	I2CHW_EnableInt();
	I2CHW_InitRamRead(txRxBuffer,TAILLEBUF);	// déclaration des buffers de transmission et réception I2C
	I2CHW_InitWrite(txRxBuffer,TAILLEBUF);
	while(1) 					// boucle infinie
	{
		status = I2CHW_bReadI2CStatus();
		if( status & I2CHW_WR_COMPLETE )	// attente de la fin de lecture des données par le maître
			{
			I2CHW_ClrWrStatus();	// effacement du bit de status Wr
			I2CHW_InitWrite(txRxBuffer,TAILLEBUF);	// réinitialisation du pointeur
			}
		if( status & I2CHW_RD_COMPLETE )	// attente de la fin de réception des données du maître
			{
			I2CHW_ClrRdStatus();	// effacement du bit de status Rd
			I2CHW_InitRamRead(txRxBuffer,TAILLEBUF);	// réinitialisation du pointeur
			}
	}
}

void mesure(void)	// inter sur front montant digbuf (branché sur comparateur analogique)
{
	long temp;
	char ligne2[6];
	char ligne2_2[11] = "ms        ";
	Counter16_Stop();				// arret du compteur sur comparaison détectée
	temp=5000-Counter16_wReadCounter();	//lecture du compteur et calcul du temps
	Counter16_WritePeriod(5000);	// initialisation compteur (decompteur) a 5000
	Counter16_Start();				// on redémarre le compteur pour la prochaine fois
	txRxBuffer[0]=(temp>>8);
	txRxBuffer[1]=(temp & 0x00FF);
	LCD_Position(1,0);            	// Place le curseur du LCD deuxième ligne à gauche
	LCD_PrString(ltoa(ligne2,temp,10)); // affichage du temps sur le LCD  
	LCD_PrString(ligne2_2);         // affichage de l'unité sur le LCD 
}

void pasdemesure(void)	// inter sur compteur a 0 donc pas de rythme depuis 5s
{
	char ligne2_3[17] = "Pas de rythme ! ";
	Counter16_Stop();				// arret du compteur 
	Counter16_WritePeriod(5000);	// initialisation compteur (decompteur) a 5000
	Counter16_Start();				// on redémarre le compteur pour la prochaine fois
	txRxBuffer[0]=0;				// pas de temps !
	txRxBuffer[1]=0;
	LCD_Position(1,0);            	// Place le curseur du LCD deuxième ligne à gauche
	LCD_PrString(ligne2_3);
}